@@ -1,11 +1,6 @@
 """
 This Module will serve as an alternative and extension to opencv - hence the name
 
-Some notes re compatibility with OpenCV.
-
- 1. Sizes: OpenCV expects sizes to be passed as [W x H]. However, in following with normal matrix
-    manipulations, Images are passed as [H x W x 3]
-
 This program is free software: you can redistribute it and/or modify it under the terms of the GNU
 General Public License as published by the Free Software Foundation, either version 3 of the
 License, or (at your option) any later version.
@@ -170,6 +165,8 @@ class AffineTransform:
 
     This is different from how skimage defines the components, and has implications on how the
     decomposition happens.
+
+    Note also, that by definition, vectors are defined as [X, Y (1)]
     """
 
     AFFINE = 6
@@ -513,19 +510,16 @@ def pairwise_iou(a, b, cutoff=0, distance=False):
     :param a: First List
     :param b: Second List
     :param cutoff: A cutoff - if IoU is below this, then it is converted to +/- np.Inf (depending on
-                   distance). Default 0 (i.e. all are valid)
+            distance). Default 0 (i.e. all are valid)
     :param distance: If True, returns a distance measure (1-IoU) instead
     :return: A Matrix of size N_a by N_b
     """
     dists = np.empty([len(a), len(b)], dtype=float)
+    inadm = np.PINF if distance else np.NINF
     for a_i, a_bb in enumerate(a):
         for b_i, b_bb in enumerate(b):
             iou = a_bb.iou(b_bb)
-            dists[a_i, b_i] = (
-                (np.PINF if distance else np.NINF)
-                if (iou < cutoff)
-                else (1 - iou if distance else iou)
-            )
+            dists[a_i, b_i] = inadm if (iou < cutoff) else (1 - iou if distance else iou)
     return dists
 
 
@@ -755,7 +749,7 @@ class BoundingBox:
          2. Find the center-point of each edge
          3. Construct an axis-aligned bounding box passing through these points
 
-        Note that unless inplace=True, a new bounding box is returned and this is not mutated.
+        Note that unless inplace=True, a new bounding box is returned and the object is not mutated.
         :param affine: An Affine Transform
         :param inplace: If True, update self
         :return: self or a new bounding box.
@@ -989,6 +983,10 @@ class VideoParser:
             else None
         )
 
+    @property
+    def FourCC(self):
+        return int(self.get(cv2.CAP_PROP_FOURCC)) if self.thread is not None else None
+
     def __len__(self):
         return int(self.get(cv2.CAP_PROP_FRAME_COUNT)) if self.thread is not None else -1
 
@@ -1199,7 +1197,7 @@ class FrameGetter:
 
         else:
             _pth = os.path.join(self.Path, self.Fmt.format(item))
-            assert os.path.exists(_pth), f"Image {item} does not exist."
+            assert os.path.exists(_pth), f"Image {item} does not exist at {_pth}."
             return cv2.imread(_pth)
 
 
@@ -1213,7 +1211,10 @@ class SwCLAHE:
     Note that the algorithm is modified as follows to allow a history:
      a) Keep track of per-pixel raw-counts in a histogram.
      b) For the true lut, perform clipping based on the number of frames used in the histogram
-        computation.
+        computation
+
+    Finally, while sizes follow the WxH convention, matrices are manipulated as H x W (to follow
+    matrix convention of rows x column).
     """
 
     def __init__(self, imgSize, clipLimit=2.0, tileGridSize=(8, 8), padding="reflect"):
