@@ -58,13 +58,14 @@ def multi_way_split(y, sizes, splitter, random_state=None):
 
     :param y:  The target labels. If using a stratified splitter, then this must be the true
                targets: otherwise, it is enough to be an empty array of the same length as the data.
-    :param sizes:  The relative sizes of the three sets. Note that these should sum to 1.
+    :param sizes:  The relative sizes of the K sets. Note that these should sum to 1 (this will
+                   be enforced by dividing by the sum).
     :param splitter:  The splitting object: this allows stratified/unstratified type splits
                       (basically one of ShuffleSplit or StratifiedShuffleSplit). Note that you
                       should NOT initialise the object: this is just passing a reference to the
                       class (and not an object).
-    :param random_state: Any random state to employ
-    :return:                N-tuple of indices, one each for the N sets.
+    :param random_state:  Any random state to employ
+    :return:  K-tuple of indices, one each for the K sets.
     """
     # --- In either case, ensure that the sizes sum to 1! --- #
     sizes = npext.sum_to_one(sizes)
@@ -79,7 +80,8 @@ def multi_way_split(y, sizes, splitter, random_state=None):
     #   This is a bit trickier. We have to first split assuming that all but the first set are
     #   grouped together. We then pass the second set of targets recursively to our function,
     #   with the remaining sizes. However, when the indices are returned, they must be remapped
-    #   to the original index set, since they are indices into that set.
+    #   to the original index set, since they are indices into that set. Also, to ensure
+    #   randomness, the seed is increased by one each time.
     sub_sizes = sizes[1:]
     left, right = next(
         splitter(
